import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
//to show the title
const render = data => {
  const title = 'Amazon revenue';
  //x-axis is labelled as Year
  const xValue = d => d.Year;
  const xAxisLabel = 'Years';
  //y-axis is labelled as RevenueUSD_billions
  const yValue = d => d.RevenueUSD_billions;
  const circleRadius = 6;
  const yAxisLabel = 'RevenueUSD_billions';
  //designing the area chart
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .ticks(6)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(9)
    .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //creating the area graph
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', areaGenerator(data));
  
  svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 40)
      .text(title);
};
// url of datset from github is linked here
csv('https://gist.githubusercontent.com/vagdevi-369/38b9371416f17703c2f28a224ac9b60c/raw/57674b01cbedffb55953b2987ebd9373611c65d6/line%2520chart')
  .then(data => {
    data.forEach(d => {
      d.RevenueUSD_billions = +d.RevenueUSD_billions;
      d.Year = new Date(d.Year);
    });
    render(data);
  });